intervalsdelegate — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »
- delegates »

# intervalsdelegate

class `camelot.view.controls.delegates.intervalsdelegate.` `IntervalsDelegate`(parent=None, editable=True, **kwargs)
  Custom delegate for visualizing camelot.container.IntervalsContainer
    data:

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »
- delegates »

Comments
blog comments powered by Disqus